Mpd client — Poezio 0.9-dev documentation

# Mpd client

This plugin is here to send what you are listening to in a chat tab.

## Installation

You need python-mpd, in its python3 version.

Then you can load the plugin.

    /load mpd_client

## Configuration

You have to put the following into `mpd_client.cfg`, as explained in the Plugin configuration section.

Note

If you do not put anything, the plugin will try to connect to `localhost:6600` with no password.

    [mpd_client]
    host = the_mpd_host
    port = 6600
    password = password if necessary

## Usage

/mpd

  Usage: `/mpd [full]`

  The bare command will show the current song, artist, and album

  `/mpd full` will show the current song, artist, and album, plus a nice progress bar in color.